<template>
  <div class="register-container">
    <div class="register-card-wrapper">
      <div class="register-card">
        <!-- Header Section -->
        <div class="card-header">
          <div class="header-icon">
            <svg class="icon" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" 
                d="M18 9v3m0 0v3m0-3h3m-3 0h-3m-2-5a4 4 0 11-8 0 4 4 0 018 0zM3 20a6 6 0 0112 0v1H3v-1z" />
            </svg>
          </div>
          <h2>Create Account</h2>
          <p>Join us by creating your account</p>
        </div>

        <!-- Content Section -->
        <div class="card-content">
          <!-- Registration Form -->
          <form @submit.prevent="register" v-if="!success">
            <div class="form-group">
              <input
                v-model="email"
                type="email"
                placeholder="Email"
                required
                :disabled="loading"
              />
            </div>
            <div class="form-group">
              <input
                v-model="password"
                type="password"
                placeholder="Password"
                required
                :disabled="loading"
              />
            </div>
            <div class="form-group">
              <input
                v-model="confirmPassword"
                type="password"
                placeholder="Confirm Password"
                required
                :disabled="loading"
              />
            </div>

            <!-- Error Messages -->
            <div v-if="validationErrors.length" class="error-container">
              <div class="error-icon">
                <svg class="icon" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" 
                    d="M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z" />
                </svg>
              </div>
              <ul class="error-messages">
                <li v-for="(error, index) in validationErrors" :key="index">
                  {{ error }}
                </li>
              </ul>
            </div>

            <button class="button primary" type="submit" :disabled="loading">
              <div v-if="loading" class="button-spinner"></div>
              <span v-else>Create Account</span>
            </button>
          </form>

          <!-- Success Message -->
          <div v-if="success" class="success-container">
            <div class="success-icon">
              <svg class="icon" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7" />
              </svg>
            </div>
            <h3>Registration Successful!</h3>
            <p>Please check your email for verification instructions.</p>
            <button class="button primary" @click="$router.push('/login')">
              Go to Login
            </button>
          </div>
        </div>
      </div>

      <!-- Footer -->
      <p class="footer-text">
        Already have an account? 
        <a href="#" class="support-link" @click.prevent="$router.push('/login')">Sign in here</a>
      </p>
    </div>
  </div>
</template>

<script>
import axios from "axios";

export default {
  data() {
    return {
      email: "",
      password: "",
      confirmPassword: "",
      loading: false,
      success: false,
      validationErrors: [],
    };
  },
  methods: {
    async register() {
      this.loading = true;
      this.validationErrors = [];

      if (this.password !== this.confirmPassword) {
        this.validationErrors.push("Passwords do not match.");
        this.loading = false;
        return;
      }

      try {
        await axios.post(
          "/api/register",
          {
            email: this.email,
            password: this.password,
          },
          {
            headers: {
              "Content-Type": "application/ld+json",
            },
          }
        );
        this.success = true;
        this.email = "";
        this.password = "";
        this.confirmPassword = "";
      } catch (error) {
        if (error.response && error.response.status === 422) {
          const violations = error.response.data.violations || [];
          this.validationErrors = violations.map(
            (violation) => `${violation.propertyPath}: ${violation.message}`
          );
        } else {
          console.error("Registration failed:", error);
        }
      } finally {
        this.loading = false;
      }
    },
  },
};
</script>

<style scoped>
.register-container {
  min-height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 1rem;
  background: linear-gradient(135deg, #f0f4ff 0%, #eef1ff 100%);
}

.register-card-wrapper {
  width: 100%;
  max-width: 440px;
}

.register-card {
  background: white;
  border-radius: 1rem;
  overflow: hidden;
  box-shadow: 0 10px 25px rgba(0, 0, 0, 0.1);
}

.card-header {
  background: linear-gradient(to right, #3b82f6, #4f46e5);
  padding: 2rem 1.5rem;
  text-align: center;
  color: white;
}

.header-icon {
  width: 4rem;
  height: 4rem;
  margin: 0 auto 1rem;
  background: rgba(255, 255, 255, 0.1);
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  backdrop-filter: blur(4px);
}

.card-header h2 {
  font-size: 1.5rem;
  font-weight: 700;
  margin: 0 0 0.5rem;
}

.card-header p {
  color: rgba(255, 255, 255, 0.9);
  margin: 0;
}

.card-content {
  padding: 2rem 1.5rem;
}

.form-group {
  margin-bottom: 1rem;
}

.form-group input {
  width: 100%;
  padding: 0.875rem 1rem;
  border: 1px solid #e5e7eb;
  border-radius: 0.5rem;
  font-size: 1rem;
  transition: all 0.2s;
  background: #f9fafb;
  box-sizing: border-box;
}

.form-group input:focus {
  outline: none;
  border-color: #3b82f6;
  background: white;
  box-shadow: 0 0 0 4px rgba(59, 130, 246, 0.1);
}

.form-group input:disabled {
  background: #f3f4f6;
  cursor: not-allowed;
}

.error-container {
  background: #fee2e2;
  border-radius: 0.5rem;
  padding: 1rem;
  margin-bottom: 1rem;
  display: flex;
  align-items: flex-start;
  gap: 0.75rem;
}

.error-icon {
  width: 1.25rem;
  height: 1.25rem;
  color: #dc2626;
  flex-shrink: 0;
  margin-top: 0.125rem;
}

.error-messages {
  list-style: none;
  padding: 0;
  margin: 0;
  color: #dc2626;
  font-size: 0.875rem;
}

.error-messages li {
  margin-bottom: 0.25rem;
}

.error-messages li:last-child {
  margin-bottom: 0;
}

.success-container {
  text-align: center;
  padding: 1rem;
}

.success-icon {
  width: 3rem;
  height: 3rem;
  margin: 0 auto 1rem;
  background: #dcfce7;
  color: #16a34a;
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
}

.success-container h3 {
  color: #16a34a;
  font-size: 1.25rem;
  font-weight: 600;
  margin-bottom: 0.5rem;
}

.success-container p {
  color: #4b5563;
  margin-bottom: 1.5rem;
}

.button {
  display: flex;
  width: 100%;
  padding: 0.875rem 1rem;
  border-radius: 0.5rem;
  font-weight: 500;
  justify-content: center;
  align-items: center;
  transition: all 0.2s;
  cursor: pointer;
  border: none;
  font-size: 1rem;
}

.button.primary {
  background: linear-gradient(to right, #3b82f6, #4f46e5);
  color: white;
  box-shadow: 0 4px 12px rgba(59, 130, 246, 0.25);
}

.button.primary:hover:not(:disabled) {
  background: linear-gradient(to right, #2563eb, #4338ca);
}

.button.primary:disabled {
  opacity: 0.7;
  cursor: not-allowed;
}

.button-spinner {
  width: 1.25rem;
  height: 1.25rem;
  border: 2px solid white;
  border-top-color: transparent;
  border-radius: 50%;
  animation: spin 0.8s linear infinite;
}

@keyframes spin {
  to {
    transform: rotate(360deg);
  }
}

.footer-text {
  text-align: center;
  color: #4b5563;
  font-size: 0.875rem;
  margin-top: 1rem;
}

.support-link {
  color: #3b82f6;
  text-decoration: none;
  font-weight: 500;
}

.support-link:hover {
  color: #2563eb;
}

.icon {
  width: 1.5rem;
  height: 1.5rem;
}

/* Responsive adjustments */
@media (max-width: 640px) {
  .register-container {
    padding: 1rem;
  }
  
  .card-header {
    padding: 1.5rem 1rem;
  }
  
  .card-content {
    padding: 1.5rem 1rem;
  }
}
</style>